<?php

namespace Drupal\pagedesigner_image\Plugin\pagedesigner\Handler;

use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner_media\Plugin\MediaFieldHandlerBase;

/**
 * Process entities of type "image".
 *
 * @PagedesignerHandler(
 *   id = "image",
 *   name = @Translation("Image handler"),
 *   types = {
 *      "image",
 *      "img",
 *   },
 * )
 */
class Image extends MediaFieldHandlerBase {

  /**
   * {@inheritdoc}
   */
  public function collectAttachments(array &$attachments) {
    $attachments['library'][] = 'pagedesigner_image/pagedesigner';
  }

  /**
   * {@inheritdoc}
   */
  public function serialize(Element $entity, array &$result = []) {
    $data = [
      'src' => '',
      'id' => $entity->field_media->target_id,
    ];
    if ($entity->field_media->entity != NULL && $entity->field_media->entity->field_media_image->entity != NULL) {
      $data['src'] = $entity->field_media->entity->field_media_image->entity->createFileUrl(FALSE);
    }
    $result = $data + $result;
  }

  /**
   * {@inheritdoc}
   */
  public function get(Element $entity, string &$result = '') {
    if ($entity->field_media->entity != NULL && $entity->field_media->entity->field_media_image->entity != NULL) {
      $file = $entity->field_media->entity->field_media_image->entity;
      $style = \Drupal::entityTypeManager()
        ->getStorage('image_style')
        ->load('ali_placeholder');
      if ($style != NULL) {
        $result = $style->buildUrl($file->getFileUri());
        return;
      }
      $style = \Drupal::entityTypeManager()
        ->getStorage('image_style')
        ->load('pagedesigner_default');
      if ($style != NULL) {
        $result = $style->buildUrl($file->getFileUri());
        return;
      }
      $result = $file->createFileUrl(FALSE);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function generate($definition, array $data, Element &$entity = NULL) {
    parent::generate(['type' => 'image', 'name' => 'image'], $data, $entity);
  }

}
