<?php

namespace Drupal\pagedesigner_media\Plugin;

use Drupal\pagedesigner\Entity\Element;
use Drupal\pagedesigner\Plugin\PlainFieldHandlerBase;

/**
 * Povides the media field handler base class for pagedesigner elements.
 *
 * The media handler provides methods for handling
 * media trait pagedesigner elements (e.g. audio, image etc.)
 * It is to be extended and the inherited class
 * to be annotated for the correct type of pagedesiger element.
 */
class MediaFieldHandlerBase extends PlainFieldHandlerBase {

  /**
   * {@inheritdoc}
   */
  public function serialize(Element $entity, array &$result = []) {
    $data = [
      'src' => '',
      'id' => $entity->field_media->target_id,
    ];
    if ($entity->field_media->entity != NULL && $entity->field_media->entity->field_media_file->entity != NULL) {
      $data['src'] = $entity->field_media->entity->field_media_file->entity->createFileUrl(FALSE);
    }
    $result = $data + $result;
  }

  /**
   * {@inheritdoc}
   */
  public function get(Element $entity, string &$result = '') {
    if ($entity->field_media->entity != NULL && $entity->field_media->entity->field_media_file->entity != NULL) {
      $result = $entity->field_media->entity->field_media_file->entity->createFileUrl(FALSE);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function patch(Element $entity, array $data) {
    if (!empty($data['id'])) {
      $entity->field_media->target_id = $data['id'];
      $entity->saveEdit();
    }
  }

}
