<?php

namespace Drupal\pagedesigner;

use Drupal\Core\DependencyInjection\ContainerInjectionInterface;
use Drupal\Core\Entity\EntityManagerInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 *
 */
class PagedesignerPatternPermissions implements ContainerInjectionInterface {

  use StringTranslationTrait;

  /**
   * The entity manager.
   *
   * @var \Drupal\Core\Entity\EntityManagerInterface
   */
  protected $entityManager;

  /**
   * Constructs a PagedesignerPatternPermissions instance.
   *
   * @param \Drupal\Core\Entity\EntityManagerInterface $entity_manager
   *   The entity manager.
   */
  public function __construct(EntityManagerInterface $entity_manager) {
    $this->entityManager = $entity_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static($container->get('entity.manager'));
  }

  /**
   * Get permissions for Taxonomy Views Integrator.
   *
   * @return array
   *   Permissions array.
   */
  public function permissions() {
    $permissions = [];

    $patterns = \Drupal::service('plugin.manager.ui_patterns')->getDefinitions();

    ksort($patterns);
    foreach ($patterns as $pattern_id => $pattern) {
      $permissions += [
        'use pattern ' . $pattern_id => [
          'title' => $this->t('Use pattern %pattern in Pagedesigner', ['%pattern' => t($pattern->getLabel())]),
        ],
      ];

    }
    return $permissions;
  }

}
